/* ************************** */
/* DELIMITER = dtDefault      */
/* ************************** */

 CREATE TABLE COUNTRY
(
  COUNTRY COUNTRYNAME NOT NULL,
  CURRENCY Varchar(10) CHARACTER SET UTF8 NOT NULL,
  PRIMARY KEY (COUNTRY)
);
CREATE TABLE CUSTOMER
(
  CUST_NO CUSTNO NOT NULL,
  CUSTOMER Varchar(25) CHARACTER SET UTF8 NOT NULL,
  CONTACT_FIRST FIRSTNAME,
  CONTACT_LAST LASTNAME,
  PHONE_NO PHONENUMBER,
  ADDRESS_LINE1 ADDRESSLINE,
  ADDRESS_LINE2 ADDRESSLINE,
  CITY Varchar(25) CHARACTER SET UTF8,
  STATE_PROVINCE Varchar(15) CHARACTER SET UTF8,
  COUNTRY COUNTRYNAME,
  POSTAL_CODE Varchar(12) CHARACTER SET UTF8,
  ON_HOLD Char(1) DEFAULT NULL,
  PRIMARY KEY (CUST_NO)
);
CREATE TABLE DEPARTMENT
(
  DEPT_NO DEPTNO NOT NULL,
  DEPARTMENT Varchar(25) CHARACTER SET UTF8 NOT NULL,
  HEAD_DEPT DEPTNO,
  MNGR_NO EMPNO,
  BUDGET BUDGET DEFAULT 50000,
  LOCATION Varchar(15) CHARACTER SET UTF8,
  PHONE_NO PHONENUMBER DEFAULT '555-1234',
  PRIMARY KEY (DEPT_NO),
  UNIQUE (DEPARTMENT)
);
CREATE TABLE EMPLOYEE
(
  EMP_NO EMPNO NOT NULL,
  FIRST_NAME FIRSTNAME NOT NULL,
  LAST_NAME LASTNAME NOT NULL,
  PHONE_EXT Varchar(4) CHARACTER SET UTF8,
  HIRE_DATE Timestamp DEFAULT 'NOW' NOT NULL,
  DEPT_NO DEPTNO NOT NULL,
  JOB_CODE JOBCODE NOT NULL,
  JOB_GRADE JOBGRADE NOT NULL,
  JOB_COUNTRY COUNTRYNAME NOT NULL,
  SALARY SALARY DEFAULT 0 NOT NULL,
  PRIMARY KEY (EMP_NO)
);
CREATE TABLE EMPLOYEE_PROJECT
(
  EMP_NO EMPNO NOT NULL,
  PROJ_ID PROJNO NOT NULL,
  PRIMARY KEY (EMP_NO,PROJ_ID)
);
CREATE TABLE JOB
(
  JOB_CODE JOBCODE NOT NULL,
  JOB_GRADE JOBGRADE NOT NULL,
  JOB_COUNTRY COUNTRYNAME NOT NULL,
  JOB_TITLE Varchar(25) CHARACTER SET UTF8 NOT NULL,
  MIN_SALARY SALARY DEFAULT 0 NOT NULL,
  MAX_SALARY SALARY DEFAULT 0 NOT NULL,
  JOB_REQUIREMENT Blob sub_type 1,
  LANGUAGE_REQ Varchar(15) CHARACTER SET UTF8,
  PRIMARY KEY (JOB_CODE,JOB_GRADE,JOB_COUNTRY)
);
CREATE TABLE PROJECT
(
  PROJ_ID PROJNO NOT NULL,
  PROJ_NAME Varchar(20) CHARACTER SET UTF8 NOT NULL,
  PROJ_DESC Blob sub_type 1,
  TEAM_LEADER EMPNO,
  PRODUCT PRODTYPE DEFAULT 'software',
  PRIMARY KEY (PROJ_ID),
  UNIQUE (PROJ_NAME)
);
CREATE TABLE PROJ_DEPT_BUDGET
(
  FISCAL_YEAR Integer NOT NULL,
  PROJ_ID PROJNO NOT NULL,
  DEPT_NO DEPTNO NOT NULL,
  QUART_HEAD_CNT Integer,
  PROJECTED_BUDGET BUDGET DEFAULT 50000,
  PRIMARY KEY (FISCAL_YEAR,PROJ_ID,DEPT_NO)
);
CREATE TABLE SALARY_HISTORY
(
  EMP_NO EMPNO NOT NULL,
  CHANGE_DATE Timestamp DEFAULT 'NOW' NOT NULL,
  UPDATER_ID Varchar(20) CHARACTER SET UTF8 NOT NULL,
  OLD_SALARY SALARY DEFAULT 0 NOT NULL,
  PERCENT_CHANGE Double precision DEFAULT 0 NOT NULL,
  PRIMARY KEY (EMP_NO,CHANGE_DATE,UPDATER_ID)
);
CREATE TABLE SALES
(
  PO_NUMBER PONUMBER NOT NULL,
  CUST_NO CUSTNO NOT NULL,
  SALES_REP EMPNO,
  ORDER_STATUS Varchar(7) CHARACTER SET UTF8 DEFAULT 'new' NOT NULL,
  ORDER_DATE Timestamp DEFAULT 'NOW' NOT NULL,
  SHIP_DATE Timestamp,
  DATE_NEEDED Timestamp,
  PAID Char(1) DEFAULT 'n',
  QTY_ORDERED Integer DEFAULT 1 NOT NULL,
  TOTAL_VALUE Decimal(9,2) NOT NULL,
  DISCOUNT Float DEFAULT 0 NOT NULL,
  ITEM_TYPE PRODTYPE DEFAULT 'software',
  PRIMARY KEY (PO_NUMBER)
);

CREATE VIEW PHONE_LIST (EMP_NO, FIRST_NAME, LAST_NAME, PHONE_EXT, LOCATION, PHONE_NO)
AS  SELECT
    emp_no, first_name, last_name, phone_ext, location, phone_no
    FROM employee, department
    WHERE employee.dept_no = department.dept_no;

CREATE EXCEPTION CUSTOMER_CHECK
'Overdue balance -- can not ship.';
CREATE EXCEPTION CUSTOMER_ON_HOLD
'This customer is on hold.';
CREATE EXCEPTION ORDER_ALREADY_SHIPPED
'Order status is "shipped."';
CREATE EXCEPTION REASSIGN_SALES
'Reassign the sales records before deleting this employee.';
CREATE EXCEPTION UNKNOWN_EMP_ID
'Invalid employee number or project id.';
